---
title: NHN KCP 해외결제 서비스 이용방법
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 해외결제
seo:
  title: KCP 해외결제 서비스 이용안내
  description: >-
    KCP의 해외카드 서비스를 통한 해외결제 이용방법 안내드립니다. KCP의 지원결제 수단 및 특징, 입점기준, 특약 신청방법, 참고사항까지
    자세한 정보를 확인해보세요.
  keywords:
    - 해외결제
tags:
  - 'NHN KCP '
  - 해외결제
pgCompanies:
  - NHN KCP
searchTags:
  - 해외결제
  - 해외카드특약
  - 해외카드
  - 'kcp해외카드 '
  - kcp해외결제
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="NHN KCP를 통한 해외결제 이용방법을 안내 드립니다." />

### **NHN KCP의 해외카드결제 서비스 이용안내**

1. **지원결제수단**

- 해외카드 (VISA, MASTER, JCB, DINERS)

**2. 지원서비스 특징**

- 지원가능 통화 : KRW (승인/정산) , USD (NHN KCP측과 별도 협의필요)
- 결제방식 : NHN KCP결제창을 띄우는 방식으로만 가능
- 지원가능언어 : 한국어, 영어
- 정산방식 : 원화결제 - 원화정산 / 달러결제 - 달러정산 (NHN KCP측과 별도 협의 필요)
- USD 결제의 경우 입점이 어려운 편이며 대부분의 경우 KRW를 지원합니다.

**3. 입점기준**

- NHN KCP와 계약을 맺으실 사업자의 서비스가 비실물 서비스인 ‘컨텐츠’ 일 경우 입점이 불가합니다.
- 국내사업자로만 계약이 가능합니다.
- 해외 법인 사업자 계약불가
- NHN KCP를 통해 해외카드 사용 특약을 맺은 후 서비스 사용가능

**4. 참고사항**

- NHN KCP의 경우에는 해외카드 결제 시 국내 카드 결제와 비슷하게 인증시스템(3D인증)을 거쳐야하기에 인증 절차가 없는 해외 결제자들에게는 결제를 하는데 불편함이 있습니다.

**5. 특약 신청방법**

- [NHN KCP 상점관리자페이지 ↗](https://partner.kcp.co.kr/auth/login) > 고객센터 > 질문하기 > 해외카드 신청 > 내용입력 후 문의하기



<Callout title="V2 NHN KCP 연동가이드 보러가기↗" />

<Callout title="V1 NHN KCP 연동가이드 보러가기↗" />
